#!/bin/sh

components=$*
[ -z "$components" ] && components="eet evas ecore embryo edje python-evas python-ecore python-edje"

export SBOX_DEFAULT_AUTOMAKE=1.8

for build_variant in n770 n8x0 ; do
	echo "===== building packages for $build_variant ====="
	for component in $components ; do 
		echo "===== $component: preparing sources ====="
		rm -rf ./$component
		svn export https://garage.maemo.org/svn/maemo-efl/trunk/$component
		
		# Unpacking original tarball
		cd $component
		tar -zxf ../${component}_*.orig.tar.gz --strip-path 1 || exit

		# if this patch exists we have to patch here
		if [ -f debian/patches/01_dont_overwrite_changelog ] ; then
			QUILT_PATCHES=debian/patches quilt --quiltrc /dev/null push -a -f || exit
			if [ -f configure.in ] ; then
				automake
				autoconf
		        fi
		fi

		# set build_variant suffix
		PKG_VER=`dpkg-parsechangelog | sed -n 's/Version: //p'`
		NEW_VER=`echo $PKG_VER | sed "s/\($PKG_VER\)/\1.$build_variant/"`
		sed -ie "s/$PKG_VER.*)/$NEW_VER)/" debian/changelog
		rm -f debian/changeloge

		echo "===== $component: building for $build_variant ====="
		
		# FIXME: install build dependencies here
		DEB_BUILD_OPTIONS=$build_variant dpkg-buildpackage -rfakeroot -us -uc -sa -D || exit
		
		# install results
		srcname=`grep Source: debian/control |cut -f2 -d' '`
		grep '^ [a-f0-9]\+ [0-9]\+ [a-z]\+ [a-z]\+ .\+.deb' \
			../${srcname}_${NEW_VER}_*.changes | cut -f6 -d' '|sed -e 's/^/..\//' \
				| xargs fakeroot dpkg -i || exit
	done
	cd ..
done

